package sun.font;

import java.awt.Font;
import java.text.Bidi;
import java.awt.font.FontRenderContext;

public final class TextLabelFactory
{
    private final FontRenderContext frc;
    private final char[] text;
    private final Bidi bidi;
    private Bidi lineBidi;
    private final int flags;
    private int lineStart;
    private int lineLimit;
    
    public TextLabelFactory(FontRenderContext frc, char[] array, Bidi bidi, int flags) {
        this.frc = frc;
        this.text = (char[])array.clone();
        this.bidi = bidi;
        this.flags = flags;
        this.lineBidi = bidi;
        this.lineStart = 0;
        this.lineLimit = array.length;
    }
    
    public FontRenderContext getFontRenderContext() {
        return this.frc;
    }
    
    public Bidi getLineBidi() {
        return this.lineBidi;
    }
    
    public void setLineContext(int n, int n2) {
        this.lineStart = n;
        this.lineLimit = n2;
        if (this.bidi != null) {
            this.lineBidi = this.bidi.createLineBidi(n, n2);
        }
    }
    
    public ExtendedTextLabel createExtended(Font font, CoreMetrics coreMetrics, Decoration decoration, int i, int j) {
        if (i >= j || i < this.lineStart || j > this.lineLimit) {
            throw new IllegalArgumentException("bad start: " + i + " or limit: " + j);
        }
        int n = (this.lineBidi == null) ? 0 : this.lineBidi.getLevelAt(i - this.lineStart);
        int n2 = this.lineBidi != null && !this.lineBidi.baseIsLeftToRight();
        int n3 = this.flags & 0xFFFFFFF6;
        if ((n & 0x1) != 0x0) {
            n3 |= 0x1;
        }
        if (!((n2 & 0x1) == 0x0)) {
            n3 |= 0x8;
        }
        return new ExtendedTextSourceLabel(new StandardTextSource(this.text, i, j - i, this.lineStart, this.lineLimit - this.lineStart, n, n3, font, this.frc, coreMetrics), decoration);
    }
    
    public TextLabel createSimple(Font font, CoreMetrics coreMetrics, int i, int j) {
        if (i >= j || i < this.lineStart || j > this.lineLimit) {
            throw new IllegalArgumentException("bad start: " + i + " or limit: " + j);
        }
        int n = (this.lineBidi == null) ? 0 : this.lineBidi.getLevelAt(i - this.lineStart);
        int n2 = this.lineBidi != null && !this.lineBidi.baseIsLeftToRight();
        int n3 = this.flags & 0xFFFFFFF6;
        if ((n & 0x1) != 0x0) {
            n3 |= 0x1;
        }
        if (!((n2 & 0x1) == 0x0)) {
            n3 |= 0x8;
        }
        return new TextSourceLabel(new StandardTextSource(this.text, i, j - i, this.lineStart, this.lineLimit - this.lineStart, n, n3, font, this.frc, coreMetrics));
    }
}
